==> racer-0.1.1.tgz: package/lib/transaction.js <==
module.exports = {
  create: function(obj) {
    var txn;
    if (obj.ops) {
      txn = [obj.base, obj.id, obj.ops];
    } else {
      txn = [obj.base, obj.id, obj.method, obj.args];
      if (obj.meta) {
        txn.push(obj.meta);
      }
    }
    return txn;
  },
  base: function(txn, val) {
    if (val !== void 0) {
      txn[0] = val;
    }
    return txn[0];
  },
  id: function(txn, val) {
    if (val !== void 0) {
      txn[1] = val;
    }
    return txn[1];
  },
  clientIdAndVer: function(txn) {
    var res;
    res = this.id(txn).split('.');
    res[1] = parseInt(res[1], 10);
    return res;
  },
  method: function(txn, name) {
    if (name !== void 0) {
      txn[2] = name;
    }
    return txn[2];
  },
  args: function(txn, vals) {
    if (vals !== void 0) {
      txn[3] = vals;
    }
    return txn[3];
  },
  path: function(txn, val) {
    var args;
    args = this.args(txn);
    if (val !== void 0) {
      args[0] = val;
    }
    return args[0];
  },
  clientId: function(txn, newClientId) {
    var clientId, num, _ref;
    _ref = this.id(txn).split('.'), clientId = _ref[0], num = _ref[1];
    if (newClientId !== void 0) {
      this.id(txn, newClientId + '.' + num);
      return newClientId;
    }
    return clientId;
  },
  meta: function(txn, obj) {
    if (obj !== void 0) {
      txn[4] = obj;
    }
    return txn[4];
  },
  ops: function(txn, ops) {
    if (ops !== void 0) {
      txn[2] = ops;
    }
    return txn[2];
  },
  isCompound: function(txn) {
    return Array.isArray(txn[2]);
  },
  op: {
    create: function(obj) {
      var meta, op;
      op = [obj.method, obj.args];
      if (meta = obj.meta) {
        op.push(meta);
      }
      return op;
    },
    method: function(op, name) {
      if (name !== void 0) {
        op[0] = name;
      }
      return op[0];
    },
    args: function(op, vals) {
      if (vals !== void 0) {
        op[1] = vals;
      }
      return op[1];
    },
    meta: function(op, obj) {
      if (obj !== void 0) {
        op[2] = obj;
      }
      return op[2];
    }
  }
};

==> racer-0.1.3.tgz: package/lib/transaction.js <==

module.exports = {
  create: function(obj) {
    var txn;
    if (obj.ops) {
      txn = [obj.base, obj.id, obj.ops];
    } else {
      txn = [obj.base, obj.id, obj.method, obj.args];
      if (obj.meta) txn.push(obj.meta);
    }
    return txn;
  },
  base: function(txn, val) {
    if (val !== void 0) txn[0] = val;
    return txn[0];
  },
  id: function(txn, val) {
    if (val !== void 0) txn[1] = val;
    return txn[1];
  },
  clientIdAndVer: function(txn) {
    var res;
    res = this.id(txn).split('.');
    res[1] = parseInt(res[1], 10);
    return res;
  },
  method: function(txn, name) {
    if (name !== void 0) txn[2] = name;
    return txn[2];
  },
  args: function(txn, vals) {
    if (vals !== void 0) txn[3] = vals;
    return txn[3];
  },
  path: function(txn, val) {
    var args;
    args = this.args(txn);
    if (val !== void 0) args[0] = val;
    return args[0];
  },
  clientId: function(txn, newClientId) {
    var clientId, num, _ref;
    _ref = this.id(txn).split('.'), clientId = _ref[0], num = _ref[1];
    if (newClientId !== void 0) {
      this.id(txn, newClientId + '.' + num);
      return newClientId;
    }
    return clientId;
  },
  meta: function(txn, obj) {
    if (obj !== void 0) txn[4] = obj;
    return txn[4];
  },
  ops: function(txn, ops) {
    if (ops !== void 0) txn[2] = ops;
    return txn[2];
  },
  isCompound: function(txn) {
    return Array.isArray(txn[2]);
  },
  op: {
    create: function(obj) {
      var meta, op;
      op = [obj.method, obj.args];
      if (meta = obj.meta) op.push(meta);
      return op;
    },
    method: function(op, name) {
      if (name !== void 0) op[0] = name;
      return op[0];
    },
    args: function(op, vals) {
      if (vals !== void 0) op[1] = vals;
      return op[1];
    },
    meta: function(op, obj) {
      if (obj !== void 0) op[2] = obj;
      return op[2];
    }
  }
};
